==> ejc-supbid-impl-3.0.1-20220124.080804-130-sources.jar: com/ejianc/business/supbid/sub/bean/SubDetailEntity.java <==
package com.ejianc.business.supbid.sub.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包招标采购清单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_supbid_sub_detail")
public class SubDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="source_id")
    private Long sourceId; // 来源数据Id
    @TableField(value="notice_id")
    private Long noticeId; // 公告ID
    @TableField(value="source_detail_id")
    private Long sourceDetailId; // 招标采购清单ID
    @TableField(value="detail_code")
    private String detailCode; // 清单编号
    @TableField(value="detail_name")
    private String detailName; // 清单名称
    @TableField(value="content")
    private String content; // 工作内容
    @TableField(value="rule")
    private String rule; // 计量规则
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="num")
    private BigDecimal num; // 本次计划工程量
    @TableField(value="rate")
    private BigDecimal rate; // 税率
    @TableField(value="price")
    private BigDecimal price; // 单价(无税）
    @TableField(value="tax_price")
    private BigDecimal taxPrice; // 单价(含税）
    @TableField(value="mny")
    private BigDecimal mny; // 金额(无税）
    @TableField(value="tax_mny")
    private BigDecimal taxMny; // 金额(含税）
    @TableField(value="tax")
    private BigDecimal tax; // 税额
    @TableField(value="memo")
    private String memo; // 备注
    
    
    

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getNoticeId() {
        return noticeId;
    }

    public void setNoticeId(Long noticeId) {
        this.noticeId = noticeId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public String getDetailCode() {
        return detailCode;
    }

    public void setDetailCode(String detailCode) {
        this.detailCode = detailCode;
    }
    public String getDetailName() {
        return detailName;
    }

    public void setDetailName(String detailName) {
        this.detailName = detailName;
    }
    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }
    public String getRule() {
        return rule;
    }

    public void setRule(String rule) {
        this.rule = rule;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }

    public BigDecimal getRate() {
        return rate;
    }

    public void setRate(BigDecimal rate) {
        this.rate = rate;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getTaxPrice() {
        return taxPrice;
    }

    public void setTaxPrice(BigDecimal taxPrice) {
        this.taxPrice = taxPrice;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-supbid-impl-3.0.1-20230809.113353-220-sources.jar: com/ejianc/business/supbid/sub/bean/SubDetailEntity.java <==
package com.ejianc.business.supbid.sub.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包招标采购清单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_supbid_sub_detail")
public class SubDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="source_id")
    private Long sourceId; // 来源数据Id
    @TableField(value="notice_id")
    private Long noticeId; // 公告ID
    @TableField(value="source_detail_id")
    private String sourceDetailId; // 招标采购清单ID
    @TableField(value="detail_code")
    private String detailCode; // 清单编号
    @TableField(value="detail_name")
    private String detailName; // 清单名称
    @TableField(value="content")
    private String content; // 工作内容
    @TableField(value="rule")
    private String rule; // 计量规则
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="num")
    private BigDecimal num; // 本次计划工程量
    @TableField(value="rate")
    private BigDecimal rate; // 税率
    @TableField(value="price")
    private BigDecimal price; // 单价(无税）
    @TableField(value="tax_price")
    private BigDecimal taxPrice; // 单价(含税）
    @TableField(value="mny")
    private BigDecimal mny; // 金额(无税）
    @TableField(value="tax_mny")
    private BigDecimal taxMny; // 金额(含税）
    @TableField(value="tax")
    private BigDecimal tax; // 税额
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="info_price")
    private BigDecimal infoPrice; // 信息价

    public BigDecimal getInfoPrice() {
        return infoPrice;
    }

    public void setInfoPrice(BigDecimal infoPrice) {
        this.infoPrice = infoPrice;
    }
    
    

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getNoticeId() {
        return noticeId;
    }

    public void setNoticeId(Long noticeId) {
        this.noticeId = noticeId;
    }
    public String getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(String sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public String getDetailCode() {
        return detailCode;
    }

    public void setDetailCode(String detailCode) {
        this.detailCode = detailCode;
    }
    public String getDetailName() {
        return detailName;
    }

    public void setDetailName(String detailName) {
        this.detailName = detailName;
    }
    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }
    public String getRule() {
        return rule;
    }

    public void setRule(String rule) {
        this.rule = rule;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }

    public BigDecimal getRate() {
        return rate;
    }

    public void setRate(BigDecimal rate) {
        this.rate = rate;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getTaxPrice() {
        return taxPrice;
    }

    public void setTaxPrice(BigDecimal taxPrice) {
        this.taxPrice = taxPrice;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
